==> allura-1.13.0.tar.gz: allura-1.13.0/ForgeTracker/forgetracker/tests/unit/test_ticket_custom_fields_form.py <==
#       Licensed to the Apache Software Foundation (ASF) under one
#       or more contributor license agreements.  See the NOTICE file
#       distributed with this work for additional information
#       regarding copyright ownership.  The ASF licenses this file
#       to you under the Apache License, Version 2.0 (the
#       "License"); you may not use this file except in compliance
#       with the License.  You may obtain a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#       Unless required by applicable law or agreed to in writing,
#       software distributed under the License is distributed on an
#       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#       KIND, either express or implied.  See the License for the
#       specific language governing permissions and limitations
#       under the License.

from __future__ import unicode_literals
from __future__ import absolute_import
from ming.orm.ormsession import ThreadLocalORMSession
from ming.base import Object

from tg import tmpl_context as c

from forgetracker.tests.unit import TrackerTestWithModel
from forgetracker.widgets import ticket_form


class TestTicketCustomFields(TrackerTestWithModel):

    def test_it_creates_string_fields(self):
        globals_ = c.app.globals
        globals_.custom_fields = [Object(name='_iteration_number',
                                         label='Iteration Number',
                                         type='string')]
        ThreadLocalORMSession.flush_all()
        fields = ticket_form.TicketCustomFields().fields
        iteration_field = fields[0]
        assert iteration_field.label == 'Iteration Number'
        assert iteration_field.name == '_iteration_number'

==> allura-1.17.1.tar.gz: allura-1.17.1/ForgeTracker/forgetracker/tests/unit/test_ticket_custom_fields_form.py <==
#       Licensed to the Apache Software Foundation (ASF) under one
#       or more contributor license agreements.  See the NOTICE file
#       distributed with this work for additional information
#       regarding copyright ownership.  The ASF licenses this file
#       to you under the Apache License, Version 2.0 (the
#       "License"); you may not use this file except in compliance
#       with the License.  You may obtain a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#       Unless required by applicable law or agreed to in writing,
#       software distributed under the License is distributed on an
#       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#       KIND, either express or implied.  See the License for the
#       specific language governing permissions and limitations
#       under the License.

from ming.odm.odmsession import ThreadLocalODMSession
from ming.base import Object

from tg import tmpl_context as c

from forgetracker.tests.unit import TrackerTestWithModel
from forgetracker.widgets import ticket_form


class TestTicketCustomFields(TrackerTestWithModel):

    def test_it_creates_string_fields(self):
        globals_ = c.app.globals
        globals_.custom_fields = [Object(name='_iteration_number',
                                         label='Iteration Number',
                                         type='string')]
        ThreadLocalODMSession.flush_all()
        fields = ticket_form.TicketCustomFields().fields
        iteration_field = fields[0]
        assert iteration_field.label == 'Iteration Number'
        assert iteration_field.name == '_iteration_number'
